@@ -118,10 +118,8 @@ class EduLevel(Base):
 
 class EnrollmentType(Base):
     """
-    Модель "Тип поступления"
-    Статус: Выполняется
+    Тип поступления
     """
-
     __tablename__ = 'univer_enrollment_type'
 
     # Идентификатор
