@@ -886,8 +886,9 @@ class EduStatus(Base):
 
 class SettlementStatus(Base):
     """
-    Неизвестный модель
+    Статус населенного пункта
     """
+
     __tablename__ = 'univer_settlement_status'
 
     # Идентификатор
@@ -954,7 +955,7 @@ class ForeignLanguage(Base):
 
 class AdmissionReason(Base):
     """
-    Причина поступления
+    Основание для поступления
     """
     __tablename__ = 'univer_admission_reason'
 
