@@ -2,12 +2,11 @@
 Роли и пользовали внутри Univer
 """
 
-from sqlalchemy import Column, Integer, String, ForeignKey, DateTime
+from sqlalchemy import Column, Integer, String, ForeignKey, DateTime, Unicode
 from sqlalchemy.orm import relationship, backref, validates
 
 from univer_db.orm import get_base
 
-
 Base = get_base()
 
 
@@ -113,19 +112,16 @@ class Student(Base):
         'univer_education_form.education_form_id'))
     education_form = relationship('EducationForm')
 
-    # Неизвестное поле
-    settlement_status_id = Column(ForeignKey(
-        'univer_settlement_status.settlement_status_id'))
+    # Статус населенного пункта
+    settlement_status_id = Column(ForeignKey('univer_settlement_status.settlement_status_id'))
     settlement_status = relationship('SettlementStatus')
 
     # Иностранный язык
-    foreign_language_id = Column(ForeignKey(
-        'univer_foreign_language.foreign_language_id'))
+    foreign_language_id = Column(ForeignKey('univer_foreign_language.foreign_language_id'))
     foreign_language = relationship('ForeignLanguage')
 
-    # Причина поступления
-    admission_reason_id = Column(ForeignKey(
-        'univer_admission_reason.admission_reason_id'))
+    # Основание для поступления
+    admission_reason_id = Column(ForeignKey('univer_admission_reason.admission_reason_id'))
     admission_reason = relationship('AdmissionReason')
 
     # Регион
@@ -133,8 +129,7 @@ class Student(Base):
     region = relationship('Region')
 
     # Тип поступления
-    enrollment_type_id = Column(ForeignKey(
-        'univer_enrollment_type.enrollment_type_id'))
+    enrollment_type_id = Column(ForeignKey('univer_enrollment_type.enrollment_type_id'))
     enrollment_type = relationship('EnrollmentType')
 
     # Район
@@ -142,9 +137,9 @@ class Student(Base):
     district = relationship('District')
 
     # ФИО студента
-    last_name = Column('students_sname', String(100))
-    first_name = Column('students_name', String(100))
-    middle_name = Column('students_father_name', String(100))
+    last_name = Column('students_sname', Unicode(100))
+    first_name = Column('students_name', Unicode(100))
+    middle_name = Column('students_father_name', Unicode(100))
 
     # Дата рождения
     birth_date = Column('students_birth_date', DateTime)
@@ -240,6 +235,30 @@ class Student(Base):
     # Нуждается в общежитии
     need_hostel = Column('students_need_hostel', Integer)
 
+    # Сколько лет служил
+    military_served_years = Column('students_military_served', Integer, default=0)
+
+    @validates('military_served_years')
+    def validate_military_served_years(self, key, value):
+        """
+        Значение данного параметра не должно быть меньше нуля
+        """
+        if value is None:
+            return
+
+        assert value >= 0
+        return value
+
+    @property
+    def is_military_served(self):
+        """
+        Служил в армии
+        """
+        if self.military_served_years and self.military_served_years > 0:
+            return True
+
+        return False
+
     @property
     def payment_info_ru(self):
         """
@@ -269,7 +288,7 @@ class Student(Base):
             return '(бакалавриат, 4 года)'
         elif self.edu_level_id == 3:
             return 'по сокращенной образовательной программе на ' \
-                'базе среднего профессионального образования'
+                   'базе среднего профессионального образования'
         elif self.edu_level_id == 2:
             return 'по сокращенной образовательной программе на базе высшего образования'
 
@@ -282,10 +301,10 @@ class Student(Base):
             return '(бакалавриат, 4 жыл)'
         elif self.edu_level_id == 3:
             return 'орта кәсіптік білім негізінде қысқартылған білім беру ' \
-                'бағдарламасы бойынша күндізгі білім беру нысаны'
+                   'бағдарламасы бойынша күндізгі білім беру нысаны'
         elif self.edu_level_id == 2:
             return 'жоғары білім негізінде қысқартылған білім беру ' \
-                'бағдарламасы бойынша күндізгі білім беру нысаны'
+                   'бағдарламасы бойынша күндізгі білім беру нысаны'
 
     @property
     def dative_full_name_ru(self):
